@@ -9,11 +9,16 @@ class TestTrain(unittest.TestCase):
         result = os.system('tfkit-train -h')
         assert (result == 0)
 
-    def testTrain(self):
+    def testGenOneByOne(self):
         result = os.system(
             'tfkit-train --train ../demo_data/generate.csv --valid ../demo_data/generate.csv --model onebyone --config voidful/albert_chinese_tiny  --savedir ./cache/ --maxlen 20')
         print(result == 0)
 
+    def testGenWithSentLoss(self):
+        result = os.system(
+            'tfkit-train --train ../demo_data/generate.csv --valid ../demo_data/generate.csv --model onebyone-pos --config voidful/albert_chinese_tiny  --savedir ./cache/ --maxlen 20')
+        print(result == 0)
+
     def testClassify(self):
         result = os.system(
             'tfkit-train --train ../demo_data/classification.csv --valid ../demo_data/classification.csv --model classify --config voidful/albert_chinese_tiny  --savedir ./cache/ --maxlen 20')
